==> unicore-uvos-server-1.5.1-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/db/DBNotification.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Jan 26, 2008
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.db;

import java.util.List;

import org.apache.ibatis.exceptions.PersistenceException;
import org.apache.ibatis.session.SqlSession;
import org.apache.log4j.Logger;

import pl.edu.icm.unicore.uvos.api.exceptions.InternalException;
import pl.edu.icm.unicore.uvos.model.NotifyBean;


/**
 * DB operations related to VO events (who should receive mail etc.)
 * @author K. Benedyczak
 */
public class DBNotification
{
	private static final Logger log = Logger.getLogger(DBNotification.class);
	
	public DBNotification()
	{
	}
	
	public List getNotifications(String action, SqlSession sqlMap) throws InternalException
	{
		try
		{
			if (action == null)
				return sqlMap.selectList("getAllNotifications");
			return sqlMap.selectList("getNotifications", action);
		} catch (PersistenceException e)
		{
			log.error("DB error: Can't get notifications list: " + e);
			throw new InternalException("DB error: Can't get " +
					"notifications list: " + e);
		}
	}
	
	public void addNotification(String action, String groupFilter, String rcpts, SqlSession sqlMap) 
		throws InternalException
	{
		NotifyBean nb = new NotifyBean();
		nb.setOperation(action);
		nb.setGroupFilter(groupFilter);
		nb.setRecipients(rcpts);
		
		try
		{
			sqlMap.insert("insertNotify", nb);
		} catch (PersistenceException e)
		{
			log.error("DB error: Can't add notification: " + e);
			throw new InternalException("DB error: Can't add " +
					"notification: " + e);
		}
	}

	public void removeNotification(int id, SqlSession sqlMap) throws InternalException
	{
		try
		{
			sqlMap.delete("deleteNotify", id);
		} catch (PersistenceException e)
		{
			log.error("DB error: Can't delete notification " + id + ": " + e);
			throw new InternalException("DB error: Can't delete " +
					"notification" + id + ": " + e);
		}		
	}
	
	public String getNotificationGroup(int id, SqlSession sqlMap) throws InternalException
	{
		try
		{
			return (String) sqlMap.selectOne("getNotificationGroup", id);
		} catch (PersistenceException e)
		{
			log.error("DB error: Can't get notification group for id " + 
				id + ": " + e);
			throw new InternalException("DB error: Can't get " +
					"notification group for id " + id + ": " + e);
		}		
	}
}

==> unicore-uvos-server-1.6.0-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/db/DBNotification.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Jan 26, 2008
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.db;

import java.util.List;

import org.apache.ibatis.exceptions.PersistenceException;
import org.apache.ibatis.session.SqlSession;
import org.apache.log4j.Logger;

import eu.unicore.util.Log;

import pl.edu.icm.unicore.uvos.api.exceptions.InternalException;
import pl.edu.icm.unicore.uvos.model.NotifyBean;
import pl.edu.icm.unicore.uvos.util.UVOSServerProperties;


/**
 * DB operations related to VO events (who should receive mail etc.)
 * @author K. Benedyczak
 */
public class DBNotification
{
	private static final Logger log = Log.getLogger(UVOSServerProperties.LOG_PFX, DBNotification.class);
	
	public DBNotification()
	{
	}
	
	public List<?> getNotifications(String action, SqlSession sqlMap) throws InternalException
	{
		try
		{
			if (action == null)
				return sqlMap.selectList("getAllNotifications");
			return sqlMap.selectList("getNotifications", action);
		} catch (PersistenceException e)
		{
			log.error("DB error: Can't get notifications list: " + e);
			throw new InternalException("DB error: Can't get " +
					"notifications list: " + e);
		}
	}
	
	public void addNotification(String action, String groupFilter, String rcpts, SqlSession sqlMap) 
		throws InternalException
	{
		NotifyBean nb = new NotifyBean();
		nb.setOperation(action);
		nb.setGroupFilter(groupFilter);
		nb.setRecipients(rcpts);
		
		try
		{
			sqlMap.insert("insertNotify", nb);
		} catch (PersistenceException e)
		{
			log.error("DB error: Can't add notification: " + e);
			throw new InternalException("DB error: Can't add " +
					"notification: " + e);
		}
	}

	public void removeNotification(int id, SqlSession sqlMap) throws InternalException
	{
		try
		{
			sqlMap.delete("deleteNotify", id);
		} catch (PersistenceException e)
		{
			log.error("DB error: Can't delete notification " + id + ": " + e);
			throw new InternalException("DB error: Can't delete " +
					"notification" + id + ": " + e);
		}		
	}
	
	public String getNotificationGroup(int id, SqlSession sqlMap) throws InternalException
	{
		try
		{
			return (String) sqlMap.selectOne("getNotificationGroup", id);
		} catch (PersistenceException e)
		{
			log.error("DB error: Can't get notification group for id " + 
				id + ": " + e);
			throw new InternalException("DB error: Can't get " +
					"notification group for id " + id + ": " + e);
		}		
	}
}
